@@ -37,9 +37,10 @@
 
 #ifdef NC_ENABLED_SSH_TLS
 
+#include "session_wrapper.h"
+
 #include <curl/curl.h>
 #include <libssh/libssh.h>
-#include "session_wrapper.h"
 
 #endif /* NC_ENABLED_SSH_TLS */
 
@@ -880,8 +881,25 @@ nc_session_free(struct nc_session *session, void (*data_free)(void *))
     struct ly_in *msg;
     struct timespec ts;
     void *p;
+    NC_STATUS status;
 
-    if (!session || (session->status == NC_STATUS_CLOSING)) {
+    if (!session) {
+        return;
+    }
+
+    if ((session->side == NC_SERVER) && (session->flags & NC_SESSION_CALLHOME)) {
+        /* CH LOCK */
+        pthread_mutex_lock(&session->opts.server.ch_lock);
+    }
+
+    status = session->status;
+
+    if ((session->side == NC_SERVER) && (session->flags & NC_SESSION_CALLHOME)) {
+        /* CH UNLOCK */
+        pthread_mutex_unlock(&session->opts.server.ch_lock);
+    }
+
+    if (status == NC_STATUS_CLOSING) {
         return;
     }
 
@@ -948,7 +966,7 @@ nc_session_free(struct nc_session *session, void (*data_free)(void *))
             nc_session_client_msgs_unlock(session, __func__);
         }
 
-        if (session->status == NC_STATUS_RUNNING) {
+        if ((session->status == NC_STATUS_RUNNING) && nc_session_is_connected(session)) {
             /* receive any leftover messages */
             while (nc_read_msg_poll_io(session, 0, &msg) == 1) {
                 ly_in_free(msg, 1);
@@ -1117,8 +1135,6 @@ nc_server_get_cpblts_version(const struct ly_ctx *ctx, LYS_VERSION version)
     cpblts[1] = strdup("urn:ietf:params:netconf:base:1.1");
     count = 2;
 
-    /* capabilities */
-
     mod = ly_ctx_get_module_implemented(ctx, "ietf-netconf");
     if (mod) {
         if (lys_feature_value(mod, "writable-running") == LY_SUCCESS) {
@@ -1153,11 +1169,15 @@ nc_server_get_cpblts_version(const struct ly_ctx *ctx, LYS_VERSION version)
         }
     }
 
+    /* HELLO LOCK */
+    pthread_rwlock_rdlock(&server_opts.hello_lock);
+
     mod = ly_ctx_get_module_implemented(ctx, "ietf-netconf-with-defaults");
     if (mod) {
-        wd_basic_mode = ATOMIC_LOAD_RELAXED(server_opts.wd_basic_mode);
+        wd_basic_mode = server_opts.wd_basic_mode;
         if (!wd_basic_mode) {
-            VRB(NULL, "with-defaults capability will not be advertised even though \"ietf-netconf-with-defaults\" model is present, unknown basic-mode.");
+            VRB(NULL, "with-defaults capability will not be advertised even though \"ietf-netconf-with-defaults\" "
+                    "model is present, unknown basic-mode.");
         } else {
             strcpy(str, "urn:ietf:params:netconf:capability:with-defaults:1.0");
             switch (wd_basic_mode) {
@@ -1172,10 +1192,10 @@ nc_server_get_cpblts_version(const struct ly_ctx *ctx, LYS_VERSION version)
                 break;
             default:
                 ERRINT;
-                break;
+                goto unlock_error;
             }
 
-            wd_also_supported = ATOMIC_LOAD_RELAXED(server_opts.wd_also_supported);
+            wd_also_supported = server_opts.wd_also_supported;
             if (wd_also_supported) {
                 strcat(str, "&also-supported=");
                 if (wd_also_supported & NC_WD_ALL) {
@@ -1205,10 +1225,15 @@ nc_server_get_cpblts_version(const struct ly_ctx *ctx, LYS_VERSION version)
     /* models */
     u = 0;
     while ((mod = ly_ctx_get_module_iter(ctx, &u))) {
+        if (nc_server_is_mod_ignored(mod->name)) {
+            /* ignored, not part of the cababilities */
+            continue;
+        }
+
         if (!strcmp(mod->name, "ietf-yang-library")) {
             if (!mod->revision || (strcmp(mod->revision, "2016-06-21") && strcmp(mod->revision, "2019-01-04"))) {
                 ERR(NULL, "Unknown \"ietf-yang-library\" revision, only 2016-06-21 and 2019-01-04 are supported.");
-                goto error;
+                goto unlock_error;
             }
 
             /* get content-id */
@@ -1293,11 +1318,18 @@ nc_server_get_cpblts_version(const struct ly_ctx *ctx, LYS_VERSION version)
         add_cpblt(str, &cpblts, &size, &count);
     }
 
+    /* HELLO UNLOCK */
+    pthread_rwlock_unlock(&server_opts.hello_lock);
+
     /* ending NULL capability */
     add_cpblt(NULL, &cpblts, &size, &count);
 
     return cpblts;
 
+unlock_error:
+    /* HELLO UNLOCK */
+    pthread_rwlock_unlock(&server_opts.hello_lock);
+
 error:
     free(cpblts);
     return NULL;
