@@ -625,7 +625,8 @@ static int
 nc_server_ssh_compare_password(const char *stored_pw, const char *received_pw)
 {
     char *received_pw_hash = NULL;
-    struct crypt_data cdata = {0};
+    struct crypt_data *cdata;
+    int ret;
 
     NC_CHECK_ARG_RET(NULL, stored_pw, received_pw, 1);
 
@@ -645,13 +646,23 @@ nc_server_ssh_compare_password(const char *stored_pw, const char *received_pw)
         return strcmp(stored_pw + 3, received_pw);
     }
 
-    received_pw_hash = crypt_r(received_pw, stored_pw, &cdata);
-    if (!received_pw_hash) {
-        ERR(NULL, "Hashing the password failed (%s).", strerror(errno));
+    cdata = (struct crypt_data *) calloc(sizeof(struct crypt_data), 1);
+    if (cdata == NULL) {
+        ERR(NULL, "Allocation of crypt_data struct failed.");
         return 1;
     }
 
-    return strcmp(received_pw_hash, stored_pw);
+    received_pw_hash = crypt_r(received_pw, stored_pw, cdata);
+    if (!received_pw_hash) {
+        ERR(NULL, "Hashing the password failed (%s).", strerror(errno));
+        free(cdata);
+        return 1;
+    }
+
+    ret = strcmp(received_pw_hash, stored_pw);
+    free(cdata);
+
+    return ret;
 }
 
 API int
@@ -1946,17 +1957,29 @@ nc_accept_ssh_session(struct nc_session *session, struct nc_server_ssh_opts *opt
         rc = -1;
         goto cleanup;
     }
-    if (opts->encryption_algs && ssh_bind_options_set(sbind, SSH_BIND_OPTIONS_CIPHERS_S_C, opts->encryption_algs)) {
-        rc = -1;
-        goto cleanup;
+    if (opts->encryption_algs) {
+        if (ssh_bind_options_set(sbind, SSH_BIND_OPTIONS_CIPHERS_S_C, opts->encryption_algs)) {
+            rc = -1;
+            goto cleanup;
+        }
+        if (ssh_bind_options_set(sbind, SSH_BIND_OPTIONS_CIPHERS_C_S, opts->encryption_algs)) {
+            rc = -1;
+            goto cleanup;
+        }
     }
     if (opts->kex_algs && ssh_bind_options_set(sbind, SSH_BIND_OPTIONS_KEY_EXCHANGE, opts->kex_algs)) {
         rc = -1;
         goto cleanup;
     }
-    if (opts->mac_algs && ssh_bind_options_set(sbind, SSH_BIND_OPTIONS_HMAC_S_C, opts->mac_algs)) {
-        rc = -1;
-        goto cleanup;
+    if (opts->mac_algs) {
+        if (ssh_bind_options_set(sbind, SSH_BIND_OPTIONS_HMAC_S_C, opts->mac_algs)) {
+            rc = -1;
+            goto cleanup;
+        }
+        if (ssh_bind_options_set(sbind, SSH_BIND_OPTIONS_HMAC_C_S, opts->mac_algs)) {
+            rc = -1;
+            goto cleanup;
+        }
     }
 
     /* configure the ssh banner */
