@@ -69,6 +69,20 @@ struct nc_tls_verify_cb_data {
     void *chain;                        /**< Certificate chain used to verify the client cert. */
 };
 
+/**
+ * @brief Initializes the TLS backend.
+ *
+ * Does nothing for OpenSSL, required for MbedTLS version 3.6.0 and later.
+ */
+int nc_tls_backend_init_wrap(void);
+
+/**
+ * @brief Destroys the TLS backend.
+ *
+ * Does nothing for OpenSSL, required for MbedTLS version 3.6.0 and later.
+ */
+void nc_tls_backend_destroy_wrap(void);
+
 /**
  * @brief Creates a new TLS session from the given configuration.
  *
@@ -267,8 +281,6 @@ void nc_tls_sans_destroy_wrap(void *sans);
  */
 int nc_tls_get_num_sans_wrap(void *sans);
 
-#ifdef NC_ENABLED_SSH_TLS
-
 /**
  * @brief Get the SAN value and type in the context of CTN.
  *
@@ -280,8 +292,6 @@ int nc_tls_get_num_sans_wrap(void *sans);
  */
 int nc_tls_get_san_value_type_wrap(void *sans, int idx, char **san_value, NC_TLS_CTN_MAPTYPE *san_type);
 
-#endif
-
 /**
  * @brief Get the number of certificates in a certificate chain.
  *
